SystemOrganization addCategory: #ConfigurationOfOpenDBXDriver!

Object subclass: #ConfigurationOfOpenDBXDriver
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfOpenDBXDriver'!

!ConfigurationOfOpenDBXDriver class methodsFor: 'private' stamp: 'EstebanLorenzano 12/7/2009 08:36'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfOpenDBXDriver class methodsFor: 'catalog' stamp: 'GuillermoPolito 12/13/2013 18:47'!
catalogChangeLog

	^ '
- Version 1.3 - 03/09/2013 - Added NativeBoost OpenDBX driver implementation
'! !

!ConfigurationOfOpenDBXDriver class methodsFor: 'catalog' stamp: 'GuillermoPolito 12/12/2013 20:13'!
catalogDescription

	^ 'OpenDBXDriver is a generic database driver which allows to access and query many existent database drivers such as Mysql, PGSql, Oracle, MSSql or Sqlite.'! !

!ConfigurationOfOpenDBXDriver class methodsFor: 'catalog' stamp: 'GuillermoPolito 12/13/2013 20:20'!
catalogKeyClassesAndExample

	^ 'A connection to a database is created with the ==DBXConnection== class. In order to create a connection, the corresponding settings and platform have to be specified, the connection connected and open.

	Here is an example of how to connect to a postgres database:
	[[[
platform := DBXPostgresBackend new.
settings := DBXConnectionSettings
		host: ''127.0.0.1''
		port: ''5432''
		database: ''databaseName''
		userName: ''sodbxtest''
		userPassword: ''sodbxtest''.
conn := DBXConnection 
		platform: platform
		settings: settings.
conn connect.
conn open.]]]

	Once we have a connection, querying the database and consuming the result is as simple as: [[[
aResult := connection execute: ''SELECT * FROM student''.
aResult
	rowsDo: [:row | Transcript
		show: (row valueNamed: ''age'') asString].
	]]]
'! !

!ConfigurationOfOpenDBXDriver class methodsFor: 'catalog' stamp: 'GuillermoPolito 12/13/2013 18:06'!
catalogKeywords

	^ #( relational database driver mysql oracle mssql pgsql sqlite odbc persistence )! !

!ConfigurationOfOpenDBXDriver class methodsFor: 'private' stamp: 'MarianoMartinezPeck 8/31/2011 12:14'!
ensureMetacello
        "Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
         Gofer API), then load the latest version of Metacello itself."

        Smalltalk at: #MetacelloProject ifAbsent: [ | error |
                "list of repositories to try, in case primary repository is not accessible"
                (Array 
                        with: 'http://www.squeaksource.com/MetacelloRepository' 
                        with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
                                ([
                                        Smalltalk at: #Gofer ifAbsent: [
                                        "Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
                                                self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
                                        Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
                                                gofer := goferClass new
                                                        url: repositoryUrl;
                                                        yourself.
                                                [ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
                                                gofer load ]]
                                                        on: Error
                                                        do: [ :ex |
                                                                error := ex.
                                                                Transcript 
                                                                        cr; 
                                                                        show: 'failed ensureMetacello: ';
                                                                        show: ex description printString;
                                                                        show: '...retrying'.
                                                                "try again"
                                                                ex return: nil ]) ~~ nil
                                        ifTrue: [
                                                "load 'default' group of Metacello"
                                                (Smalltalk at: #ConfigurationOfMetacello) perform: #load.
                                                ^self ]].
                "shouldn't get here unless the load failed ... throw an error"
                self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfOpenDBXDriver class methodsFor: 'metacello tool support' stamp: 'EstebanLorenzano 12/7/2009 08:36'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfOpenDBXDriver class methodsFor: 'metacello tool support' stamp: 'EstebanLorenzano 12/7/2009 08:36'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfOpenDBXDriver class methodsFor: 'loading' stamp: 'GuillermoPolito 5/5/2013 13:20'!
loadBleedingEdge
	(self project version: #bleedingEdge) load.! !

!ConfigurationOfOpenDBXDriver class methodsFor: 'loading' stamp: 'GuillermoPolito 5/5/2013 13:20'!
loadStable
	(self project version: #stable) load.! !

!ConfigurationOfOpenDBXDriver class methodsFor: 'metacello tool support' stamp: 'EstebanLorenzano 12/7/2009 08:36'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfOpenDBXDriver class methodsFor: 'accessing' stamp: 'EstebanLorenzano 12/7/2009 08:36'!
project

	^self new project! !

!ConfigurationOfOpenDBXDriver methodsFor: 'baselines' stamp: 'GuillermoPolito 8/22/2011 18:32'!
baseline10: spec
    <version: '1.0-baseline'>
    
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DBXTalk'.

		spec project: 'FFI'
			with: [ 
				spec className: 'ConfigurationOfFFI'.
				spec loads: #( 'FFI-Pools' 'FFI-Kernel' 'FFI-Tests' ).
				spec file: 'ConfigurationOfFFI'.
				spec repository: 'http://squeaksource.com/MetacelloRepository'.
			].
	 	
		spec package: 'OpenDBXDriverSmalltalk-Dialect'.
		
		spec package: 'OpenDBXDriverPharo-Dialect'  with: [
	            spec requires: #('OpenDBXDriverSmalltalk-Dialect').
			spec postLoadDoIt: #setPharoDialect ].
	 
		spec package: 'OpenDBXDriver' with: [
	            spec requires: #('OpenDBXDriverPharo-Dialect' 'FFI') ].

		spec package: 'OpenDBXDriverTests' with: [
	            spec requires: #('OpenDBXDriver' ) ].

		spec package: 'OpenDBXDriverBenchmarks' with: [
	            spec requires: #('OpenDBXDriver' ) ].

		spec
			group: 'default' with: #('ALL');
			group: 'Core' with: #('OpenDBXDriver');
			group: 'Tests' with: #('OpenDBXDriverTests');
			group: 'Benchmarks' with: #('OpenDBXDriverBenchmarks').
            
	] ! !

!ConfigurationOfOpenDBXDriver methodsFor: 'baselines' stamp: 'GuillermoPolito 6/13/2012 11:54'!
baseline11: spec
    <version: '1.1-baseline'>
    
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DBXTalk'.

		spec project: 'FFI'
			with: [ 
				spec className: 'ConfigurationOfFFI'.
				spec loads: #( 'FFI-Pools' 'FFI-Kernel' 'FFI-Tests' ).
				spec file: 'ConfigurationOfFFI'.
				spec repository: 'http://www.squeaksource.com/MetacelloRepository'.
			].
	 	
		spec package: 'OpenDBXDriverSmalltalk-Dialect'.
		
		spec package: 'OpenDBXDriverPharo-Dialect'  with: [
	            spec requires: #('OpenDBXDriverSmalltalk-Dialect').
			spec postLoadDoIt: #setPharoDialect ].
	 
		spec package: 'OpenDBXDriver' with: [
	            spec requires: #('OpenDBXDriverPharo-Dialect' 'FFI') ].

		spec package: 'OpenDBXDriverTests' with: [
	            spec requires: #('OpenDBXDriver' ) ].

		spec package: 'OpenDBXDriverBenchmarks' with: [
	            spec requires: #('OpenDBXDriver' ) ].

		spec
			group: 'default' with: #('ALL');
			group: 'Core' with: #('OpenDBXDriver');
			group: 'Tests' with: #('OpenDBXDriverTests');
			group: 'Benchmarks' with: #('OpenDBXDriverBenchmarks');
			group: 'DeveloperGroup' with: #('Core' 'Tests' 'Benchmarks').
            
	] ! !

!ConfigurationOfOpenDBXDriver methodsFor: 'baselines' stamp: 'GuillermoPolito 3/23/2013 18:03'!
baseline12: spec
    <version: '1.2-baseline'>
    
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.squeaksource.com/DBXTalk'.

		spec project: 'FFI'
			with: [ 
				spec className: 'ConfigurationOfFFI'.
				spec loads: #( 'default' 'Tests' ).
				spec file: 'ConfigurationOfFFI'.
				spec repository: 'http://www.squeaksource.com/MetacelloRepository'.
			].
	 	
		spec package: 'OpenDBXDriverSmalltalk-Dialect'.
		
		spec package: 'OpenDBXDriverPharo-Dialect'  with: [
	            spec requires: #('OpenDBXDriverSmalltalk-Dialect').
			spec postLoadDoIt: #setPharoDialect ].
	 
		spec package: 'OpenDBXDriver' with: [
	            spec requires: #('OpenDBXDriverPharo-Dialect' 'FFI') ].

		spec package: 'OpenDBXDriverTests' with: [
	            spec requires: #('OpenDBXDriver' ) ].

		spec package: 'OpenDBXDriverBenchmarks' with: [
	            spec requires: #('OpenDBXDriver' ) ].

		spec
			group: 'default' with: #('ALL');
			group: 'Core' with: #('OpenDBXDriver');
			group: 'Tests' with: #('OpenDBXDriverTests');
			group: 'Benchmarks' with: #('OpenDBXDriverBenchmarks');
			group: 'DeveloperGroup' with: #('Core' 'Tests' 'Benchmarks').
            
	] ! !

!ConfigurationOfOpenDBXDriver methodsFor: 'baselines' stamp: 'RocioAmaya 9/3/2013 16:56'!
baseline13: spec
    <version: '1.3-baseline'>
    
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.smalltalkhub.com/mc/DBXTalk/DBXTalkDriver/main'.

		"Old FFI Bindings"
		spec project: 'FFI'
			with: [ 
				spec className: 'ConfigurationOfFFI'.
				spec loads: #( 'FFI-Pools' 'FFI-Kernel' 'FFI-Tests' ).
				spec file: 'ConfigurationOfFFI'.
				spec repository: 'http://www.squeaksource.com/MetacelloRepository'.
			].
		
		spec package: 'OpenDBXDriverPharo-FFI' with:[
			spec requires: #( 'FFI' 'OpenDBXDriverSmalltalk-Dialect').
			spec postLoadDoIt: #setFFIOpenDBX ].
		
		"New NativeBoostFFI bindings"
		spec project: 'TalkFFIRuntime'
			with: [ 
				spec className: 'ConfigurationOfTalkFFI'.
				spec loads: #( 'Runtime' ).
				spec file: 'ConfigurationOfTalkFFI'.
				spec repository: 'http://www.smalltalkhub.com/mc/CipT/TalkFFI/main'.
				spec versionString: '1.3.1'
			].
		
		spec package: 'OpenDBXDriverPharo-NativeBoost' with: [
			spec requires: #( 'LibOpenDBX' 'OpenDBXDriverSmalltalk-Dialect').
			spec postLoadDoIt: #setNBOpenDBX ].
		
		spec package: 'LibOpenDBX' with: [
			spec requires: #( 'TalkFFIRuntime' ) ].
		
		"Common"
		spec package: 'OpenDBXDriverSmalltalk-Dialect'.
		spec package: 'OpenDBXDriverPharo-Dialect'  with: [
	            spec requires: #('OpenDBXDriverSmalltalk-Dialect').
			].
	 
		spec package: 'OpenDBXDriver' with: [
	            spec requires: #('OpenDBXDriverPharo-Dialect') ].

		spec package: 'OpenDBXDriverTests' with: [
	            spec requires: #('OpenDBXDriver' ) ].

		spec package: 'OpenDBXDriverBenchmarks' with: [
	            spec requires: #('OpenDBXDriver' ) ].

		spec
			group: 'default' with: #('NBFFIDriver' 'Tests' 'Benchmarks');
			group: 'FFIDriver' with: #('Core' 'OpenDBXDriverPharo-FFI');
			group: 'NBFFIDriver' with: #('Core' 'OpenDBXDriverPharo-NativeBoost');
			group: 'Core' with: #('OpenDBXDriver');
			group: 'Tests' with: #('OpenDBXDriverTests');
			group: 'Benchmarks' with: #('OpenDBXDriverBenchmarks');
			group: 'DeveloperGroup' with: #('Core' 'FFIDriver' 'NBFFIDriver' 'Tests' 'Benchmarks').
	] ! !

!ConfigurationOfOpenDBXDriver methodsFor: 'accessing' stamp: 'DaleHenrichs 12/7/2009 16:48'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfOpenDBXDriver methodsFor: 'doits' stamp: 'RocioAmaya 8/12/2013 13:25'!
setFFIOpenDBX

	(Smalltalk at: #OpenDBX) current: (Smalltalk at: #FFIOpenDBX) ffiImplementationForOS! !

!ConfigurationOfOpenDBXDriver methodsFor: 'doits' stamp: 'RocioAmaya 8/12/2013 13:47'!
setNBOpenDBX

	(Smalltalk at: #OpenDBX) current: (Smalltalk at: #NBPharoOpenDBX) ! !

!ConfigurationOfOpenDBXDriver methodsFor: 'doits' stamp: 'MarianoMartinezPeck 5/7/2011 00:40'!
setPharoDialect

	(Smalltalk at: #OpenDBXDriverSmalltalkDialect)
		current: (Smalltalk at: #OpenDBXDriverPharoDialect)! !

!ConfigurationOfOpenDBXDriver methodsFor: 'versions' stamp: 'GuillermoPolito 3/23/2013 18:04'!
stable: spec 
	<symbolicVersion: #stable>
	 
	spec for: #'pharo1.2.x' version: '1.01'. 
	spec for: #'pharo1.3.x' version: '1.01'. 
	spec for: #'pharo1.4.x' version: '1.1'.
	spec for: #'pharo2.0.x' version: '1.2'.! !

!ConfigurationOfOpenDBXDriver methodsFor: 'versions' stamp: 'GuillermoPolito 1/6/2012 03:05'!
version101: spec
	<version: '1.01' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec description: 'some fixes to the test tables'.
		spec blessing: #stable.
		
		spec project: 'FFI' with: '1.3'.
		spec package: 'OpenDBXDriver' 
			with: 'OpenDBXDriver-GuillermoPolito.35'.
		spec package: 'OpenDBXDriverTests' 
			with: 'OpenDBXDriverTests-GuillermoPolito.17'.
		spec package: 'OpenDBXDriverBenchmarks' 
			with: 'OpenDBXDriverBenchmarks-MarianoMartinezPeck.1'.
		spec package: 'OpenDBXDriverSmalltalk-Dialect' 
			with: 'OpenDBXDriverSmalltalk-Dialect-MarianoMartinezPeck.2'.
		spec package: 'OpenDBXDriverPharo-Dialect' 
			with: 'OpenDBXDriverPharo-Dialect-MarianoMartinezPeck.2'.
		]! !

!ConfigurationOfOpenDBXDriver methodsFor: 'versions' stamp: 'GuillermoPolito 8/23/2011 17:24'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #stable.
		
		spec project: 'FFI' with: '1.3'.
		spec package: 'OpenDBXDriver' 
			with: 'OpenDBXDriver-GuillermoPolito.30'.
		spec package: 'OpenDBXDriverTests' 
			with: 'OpenDBXDriverTests-GuillermoPolito.13'.
		spec package: 'OpenDBXDriverBenchmarks' 
			with: 'OpenDBXDriverBenchmarks-MarianoMartinezPeck.1'.
		spec package: 'OpenDBXDriverSmalltalk-Dialect' 
			with: 'OpenDBXDriverSmalltalk-Dialect-MarianoMartinezPeck.2'.
		spec package: 'OpenDBXDriverPharo-Dialect' 
			with: 'OpenDBXDriverPharo-Dialect-MarianoMartinezPeck.2'.
		]! !

!ConfigurationOfOpenDBXDriver methodsFor: 'versions' stamp: 'GuillermoPolito 6/13/2012 11:52'!
version11: spec
	<version: '1.1' imports: #('1.1-baseline')>
	
	spec for: #common do: [
		spec description: 'some fixes to the test tables'.
		spec blessing: #stable.
		
		spec project: 'FFI' with: '1.5'.
		spec package: 'OpenDBXDriver' 
			with: 'OpenDBXDriver-GuillermoPolito.35'.
		spec package: 'OpenDBXDriverTests' 
			with: 'OpenDBXDriverTests-GuillermoPolito.17'.
		spec package: 'OpenDBXDriverBenchmarks' 
			with: 'OpenDBXDriverBenchmarks-MarianoMartinezPeck.1'.
		spec package: 'OpenDBXDriverSmalltalk-Dialect' 
			with: 'OpenDBXDriverSmalltalk-Dialect-MarianoMartinezPeck.2'.
		spec package: 'OpenDBXDriverPharo-Dialect' 
			with: 'OpenDBXDriverPharo-Dialect-MarianoMartinezPeck.2'.
		]! !

!ConfigurationOfOpenDBXDriver methodsFor: 'versions' stamp: 'GuillermoPolito 3/23/2013 18:04'!
version12: spec
	<version: '1.2' imports: #('1.2-baseline')>
	
	spec for: #common do: [
		spec description: 'some fixes to the test tables'.
		spec blessing: #stable.
		
		spec project: 'FFI' with: '1.7'.
		spec package: 'OpenDBXDriver' 
			with: 'OpenDBXDriver-GuillermoPolito.35'.
		spec package: 'OpenDBXDriverTests' 
			with: 'OpenDBXDriverTests-GuillermoPolito.17'.
		spec package: 'OpenDBXDriverBenchmarks' 
			with: 'OpenDBXDriverBenchmarks-MarianoMartinezPeck.1'.
		spec package: 'OpenDBXDriverSmalltalk-Dialect' 
			with: 'OpenDBXDriverSmalltalk-Dialect-MarianoMartinezPeck.2'.
		spec package: 'OpenDBXDriverPharo-Dialect' 
			with: 'OpenDBXDriverPharo-Dialect-MarianoMartinezPeck.2'.
		]! !

!ConfigurationOfOpenDBXDriver methodsFor: 'versions' stamp: 'RocioAmaya 9/3/2013 16:56'!
version13: spec
	<version: '1.3' imports: #('1.3-baseline')>
	
	spec for: #common do: [
		spec description: 'some fixes to the test tables'.
		spec blessing: #development.
		
		"Old FFI Bindings"
		spec project: 'FFI' with: '1.7'.
		spec package: 'OpenDBXDriverPharo-FFI' with: 'OpenDBXDriverPharo-FFI-RocioAmaya.4'.
		
		"New NativeBoostBindings"
		spec project: 'TalkFFIRuntime' with: '1.3.1'.
		spec package: 'OpenDBXDriverPharo-NativeBoost' with: 'OpenDBXDriverPharo-NativeBoost-RocioAmaya.3'.
		spec package: 'LibOpenDBX' with: 'LibOpenDBX-RocioAmaya.1'.
		
		"Common packages"
		spec package: 'OpenDBXDriver' 
			with: 'OpenDBXDriver-GuillermoPolito.39'.
		spec package: 'OpenDBXDriverTests' 
			with: 'OpenDBXDriverTests-GuillermoPolito.21'.
		spec package: 'OpenDBXDriverBenchmarks' 
			with: 'OpenDBXDriverBenchmarks-MarianoMartinezPeck.1'.
		spec package: 'OpenDBXDriverSmalltalk-Dialect' 
			with: 'OpenDBXDriverSmalltalk-Dialect-RocioAmaya.5'.
		spec package: 'OpenDBXDriverPharo-Dialect' 
			with: 'OpenDBXDriverPharo-Dialect-RocioAmaya.3'.
		]! !
